==> nimble_0.6-4.tar.gz: nimble/R/registration.R <==

if(!exists('.NimbleUseRegistration') || !.NimbleUseRegistration) {
   resizeManyModelVarAccessor = 'resizeManyModelVarAccessor'
   resizeManyModelValuesAccessor = 'resizeManyModelValuesAccessor'
   getAvailableNames = 'getAvailableNames'
   getModelObjectPtr = 'getModelObjectPtr'
   getModelValuesMemberElement = 'getModelValuesMemberElement'
   getNRow = 'getNRow'
   addBlankModelValueRows = 'addBlankModelValueRows'
   copyModelValuesElements = 'copyModelValuesElements'
   setMVElement = 'setMVElement'
   getMVElement = 'getMVElement'
   R_setPtrVectorOfPtrs = 'setPtrVectorOfPtrs'
   R_setOnePtrVectorOfPtrs = 'setOnePtrVectorOfPtrs'
   R_setDoublePtrFromSinglePtr = 'setDoublePtrFromSinglePtr'
   R_setSmartPtrFromSinglePtr = 'setSmartPtrFromSinglePtr'
  ## R_setSinglePtrFromSinglePtr = 'setSinglePtrFromSinglePtr'
   C_dwish_chol = 'C_dwish_chol'
   C_rwish_chol = 'C_rwish_chol'
   C_ddirch = 'C_ddirch'
   C_rdirch = 'C_rdirch'
   C_dmulti = 'C_dmulti'
   C_rmulti = 'C_rmulti'
   C_dcat = 'C_dcat'
   C_rcat = 'C_rcat'
   C_dinterval = 'C_dinterval'
   C_rinterval = 'C_rinterval'
   C_dt_nonstandard = 'C_dt_nonstandard'
   C_rt_nonstandard = 'C_rt_nonstandard'
   C_pt_nonstandard = 'C_pt_nonstandard'
   C_qt_nonstandard = 'C_qt_nonstandard'
   C_dexp_nimble = 'C_dexp_nimble'
   C_rexp_nimble = 'C_rexp_nimble'
   C_pexp_nimble = 'C_pexp_nimble'
   C_qexp_nimble = 'C_qexp_nimble'
   C_dinvgamma = 'C_dinvgamma'
   C_rinvgamma = 'C_rinvgamma'
   C_pinvgamma = 'C_pinvgamma'
   C_qinvgamma = 'C_qinvgamma'
   C_dmnorm_chol = 'C_dmnorm_chol'
   C_rmnorm_chol = 'C_rmnorm_chol'
   C_dmvt_chol = 'C_dmvt_chol'
   C_rmvt_chol = 'C_rmvt_chol'
   makeNumericList = 'makeNumericList'
   newModelValues = 'newModelValues'
   testRows = 'testRows'
   }

==> nimble_0.6-5.tar.gz: nimble/R/registration.R <==

if(!exists('.NimbleUseRegistration') || !.NimbleUseRegistration) {
   resizeManyModelVarAccessor = 'resizeManyModelVarAccessor'
   resizeManyModelValuesAccessor = 'resizeManyModelValuesAccessor'
   getAvailableNames = 'getAvailableNames'
   getModelObjectPtr = 'getModelObjectPtr'
   getModelValuesMemberElement = 'getModelValuesMemberElement'
   getNRow = 'getNRow'
   addBlankModelValueRows = 'addBlankModelValueRows'
   copyModelValuesElements = 'copyModelValuesElements'
   setMVElement = 'setMVElement'
   getMVElement = 'getMVElement'
   R_setPtrVectorOfPtrs = 'setPtrVectorOfPtrs'
   R_setOnePtrVectorOfPtrs = 'setOnePtrVectorOfPtrs'
   R_setDoublePtrFromSinglePtr = 'setDoublePtrFromSinglePtr'
   R_setSmartPtrFromSinglePtr = 'setSmartPtrFromSinglePtr'
  ## R_setSinglePtrFromSinglePtr = 'setSinglePtrFromSinglePtr'
   C_dwish_chol = 'C_dwish_chol'
   C_rwish_chol = 'C_rwish_chol'
   C_dinvwish_chol = 'C_dinvwish_chol'
   C_rinvwish_chol = 'C_rinvwish_chol'
   C_ddirch = 'C_ddirch'
   C_rdirch = 'C_rdirch'
   C_dmulti = 'C_dmulti'
   C_rmulti = 'C_rmulti'
   C_dcat = 'C_dcat'
   C_rcat = 'C_rcat'
   C_dinterval = 'C_dinterval'
   C_rinterval = 'C_rinterval'
   C_dt_nonstandard = 'C_dt_nonstandard'
   C_rt_nonstandard = 'C_rt_nonstandard'
   C_pt_nonstandard = 'C_pt_nonstandard'
   C_qt_nonstandard = 'C_qt_nonstandard'
   C_dexp_nimble = 'C_dexp_nimble'
   C_rexp_nimble = 'C_rexp_nimble'
   C_pexp_nimble = 'C_pexp_nimble'
   C_qexp_nimble = 'C_qexp_nimble'
   C_dinvgamma = 'C_dinvgamma'
   C_rinvgamma = 'C_rinvgamma'
   C_pinvgamma = 'C_pinvgamma'
   C_qinvgamma = 'C_qinvgamma'
   C_dsqrtinvgamma = 'C_dsqrtinvgamma'
   C_rsqrtinvgamma = 'C_rsqrtinvgamma'
   C_dmnorm_chol = 'C_dmnorm_chol'
   C_rmnorm_chol = 'C_rmnorm_chol'
   C_dmvt_chol = 'C_dmvt_chol'
   C_rmvt_chol = 'C_rmvt_chol'
   makeNumericList = 'makeNumericList'
   newModelValues = 'newModelValues'
   testRows = 'testRows'
   }
